DROP database if exists `bill-platform`;
CREATE database `bill-platform` default charset=utf8;
use `bill-platform`;

SET NAMES utf8mb4;
SET FOREIGN_KEY_CHECKS = 0;

-- ----------------------------
-- Table structure for mortals_xhx_access
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_access`;
CREATE TABLE `mortals_xhx_access`  (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `area_id` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '区域Id',
  `area_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '区域名称',
  `area_code` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '区域编码',
  `site_id` bigint(20) NULL DEFAULT NULL COMMENT '站点Id',
  `site_code` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '站点编码',
  `site_name` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '站点名称',
  `big_path` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '背景图片地址',
  `icon` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '图标',
  `tag` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '标签',
  `latitude` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '维度',
  `longitude` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '经度',
  `access_time` datetime(0) NULL DEFAULT CURRENT_TIMESTAMP(0),
  `type` varchar(16) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '类型' COMMENT '接入类型 (area.区域,site.站点)',
  `sort` int(4) NULL DEFAULT 0 COMMENT '排序',
  `remark` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '备注',
  `content` varchar(2048) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '',
  `create_user_id` bigint(20) NULL DEFAULT NULL COMMENT '创建用户',
  `create_time` datetime(0) NULL DEFAULT NULL COMMENT '创建时间',
  `update_time` datetime(0) NULL DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '区域接入' ROW_FORMAT = Dynamic;

-- ----------------------------
-- Records of mortals_xhx_access
-- ----------------------------

-- ----------------------------
-- Table structure for mortals_xhx_access_stat_log
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_access_stat_log`;
CREATE TABLE `mortals_xhx_access_stat_log`  (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `access_id` bigint(20) NULL DEFAULT 0 COMMENT '接入Id',
  `site_id` bigint(20) NULL DEFAULT NULL COMMENT '站点Id',
  `site_code` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '站点编码',
  `site_name` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '站点名称',
  `stat_start_time` datetime(0) NULL DEFAULT NULL COMMENT '统计开始时间',
  `stat_end_time` datetime(0) NULL DEFAULT NULL COMMENT '统计结束时间',
  `duration` bigint(20) NULL DEFAULT 0 COMMENT '站点Id',
  `type` varchar(16) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '全部' COMMENT '类型 (ALL.全部,PJQ.评价器,PDJ.排队机)',
  `remark` varchar(256) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '备注',
  `create_user_id` bigint(20) NULL DEFAULT NULL COMMENT '创建用户',
  `create_time` datetime(0) NULL DEFAULT NULL COMMENT '创建时间',
  `update_time` datetime(0) NULL DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '统计日志表' ROW_FORMAT = Dynamic;

-- ----------------------------
-- Records of mortals_xhx_access_stat_log
-- ----------------------------

-- ----------------------------
-- Table structure for mortals_xhx_access_system
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_access_system`;
CREATE TABLE `mortals_xhx_access_system`  (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `accessId` bigint(20) NULL DEFAULT NULL COMMENT '接入区域ID',
  `system_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '接入系统名称',
  `system_code` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '接入系统编码',
  `enabled` tinyint(2) NULL DEFAULT 0 COMMENT '启用状态 (0.停止，1.启用)',
  `access_time` datetime(0) NULL DEFAULT NULL COMMENT '接入开通时间',
  `sort` int(4) NULL DEFAULT 0 COMMENT '排序',
  `remark` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '备注',
  `create_user_id` bigint(20) NULL DEFAULT NULL COMMENT '创建用户',
  `create_time` datetime(0) NOT NULL COMMENT '创建时间',
  `update_time` datetime(0) NULL DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '区域接入系统' ROW_FORMAT = Dynamic;

-- ----------------------------
-- Records of mortals_xhx_access_system
-- ----------------------------

-- ----------------------------
-- Table structure for mortals_xhx_dimension
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_dimension`;
CREATE TABLE `mortals_xhx_dimension`  (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `dimension_code` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '维度编码',
  `dimension_name` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '维度名称',
  `dimension_value` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '维度值',
  `dimension_type` tinyint(2) NULL DEFAULT 1 COMMENT '维度类型(1.固定值,2.系统上下问变量)',
  `createTime` datetime(0) NULL DEFAULT NULL COMMENT '创建时间',
  `createUserId` bigint(20) NULL DEFAULT NULL COMMENT '创建用户',
  `updateUserId` bigint(20) NULL DEFAULT NULL COMMENT '更新用户',
  `updateTime` datetime(0) NULL DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 4 CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '授权维度' ROW_FORMAT = Dynamic;

-- ----------------------------
-- Records of mortals_xhx_dimension
-- ----------------------------
INSERT INTO `mortals_xhx_dimension` VALUES (1, 'siteId', '所属站点', 'siteIds', 2, '2024-05-16 13:45:11', NULL, NULL, NULL);
INSERT INTO `mortals_xhx_dimension` VALUES (2, 'num', '数量', '100', 1, '2024-05-16 13:46:36', NULL, NULL, NULL);
INSERT INTO `mortals_xhx_dimension` VALUES (3, 'dept', '部门', 'deptId', 1, NULL, NULL, NULL, NULL);

-- ----------------------------
-- Table structure for mortals_xhx_dimension_resource_rule
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_dimension_resource_rule`;
CREATE TABLE `mortals_xhx_dimension_resource_rule`  (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `role_id` bigint(20) NULL DEFAULT NULL COMMENT '角色ID',
  `resource_id` bigint(20) NULL DEFAULT NULL COMMENT '资源ID',
  `rule_code` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '规则编码',
  `rule_name` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '规则名称',
  `rule_condition` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT 'IN' COMMENT '规则条件(属于.IN,小于.<,大于.>,等于.=,不等于.!=,大于等于>=,小于等于.<=,左模糊.like %,右模糊.like %)',
  `rule_value` varchar(512) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '规则值,固定值或者系统变量',
  `rule_type` tinyint(2) NULL DEFAULT 1 COMMENT '规则值类型(1.固定值,2.系统上下问变量)',
  `create_time` datetime(0) NULL DEFAULT NULL COMMENT '创建时间',
  `create_user_id` bigint(20) NULL DEFAULT NULL COMMENT '创建用户',
  `update_user_id` bigint(20) NULL DEFAULT NULL COMMENT '更新用户',
  `update_time` datetime(0) NULL DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 4 CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '角色资源维度规则表' ROW_FORMAT = Dynamic;

-- ----------------------------
-- Records of mortals_xhx_dimension_resource_rule
-- ----------------------------
INSERT INTO `mortals_xhx_dimension_resource_rule` VALUES (1, 1, 150031, 'siteId', '所属站点', 'IN', 'siteIds', 2, '2024-05-16 13:49:03', NULL, NULL, NULL);
INSERT INTO `mortals_xhx_dimension_resource_rule` VALUES (2, 1, 150031, 'productName', '所属产品名称', 'IN', '评价器', 1, '2024-05-16 13:49:44', NULL, NULL, NULL);
INSERT INTO `mortals_xhx_dimension_resource_rule` VALUES (3, 1, 150032, 'deptId', '所属部门', '>', 'deptId', 2, NULL, NULL, NULL, NULL);

-- ----------------------------
-- Table structure for mortals_xhx_idgenerator
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_idgenerator`;
CREATE TABLE `mortals_xhx_idgenerator`  (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `idType` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT 'id类型',
  `idMaxValue` bigint(20) UNSIGNED NOT NULL COMMENT 'id值',
  `remark` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '备注',
  `versionNum` bigint(20) UNSIGNED NOT NULL DEFAULT 0 COMMENT '版本号，默认0',
  `gmtModify` timestamp(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0) ON UPDATE CURRENT_TIMESTAMP(0) COMMENT '最后修改时间',
  `createTime` datetime(0) NULL DEFAULT NULL COMMENT '创建时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 2 CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '主键Id生成器' ROW_FORMAT = Dynamic;

-- ----------------------------
-- Records of mortals_xhx_idgenerator
-- ----------------------------
INSERT INTO `mortals_xhx_idgenerator` VALUES (1, 'INFO_VERSION_KEY', 1, '基础信息版本号生成因子', 0, '2019-04-18 18:00:00', NULL);

-- ----------------------------
-- Table structure for mortals_xhx_menu
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_menu`;
CREATE TABLE `mortals_xhx_menu`  (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '菜单ID，主键，自增长',
  `name` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '菜单名称',
  `url` varchar(256) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '路由地址',
  `ancestors` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '当前节点父id路径，“，”分割',
  `parentId` bigint(20) NULL DEFAULT NULL COMMENT '父菜单ID，一级菜单的该字段值为-1',
  `linkType` tinyint(2) NULL DEFAULT 0 COMMENT '链接方式 (0.普通，1.弹出，2.脚本)',
  `imgPath` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '主菜单图标，主菜单图标的css样式名',
  `buttonImgPath` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '按钮图标，按钮图标的css样式名',
  `imgCommPath` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '常用菜单图标，常用菜单图标的css样式名',
  `commMenu` tinyint(2) NULL DEFAULT 1 COMMENT '是否常用菜单 (0.非常用，1.常用)',
  `component` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT 'vue组件路径',
  `menuType` tinyint(2) NULL DEFAULT 0 COMMENT '菜单类型 (0.目录，1.菜单，2.按钮)',
  `authType` tinyint(2) NULL DEFAULT 3 COMMENT '权限类型 (0.无限制，1.无需登录查看，2.需要登录查看，3.需要角色权限查看)',
  `visible` tinyint(2) NULL DEFAULT 0 COMMENT '菜单显示状态 (0.显示，1.隐藏)',
  `perms` varchar(512) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '权限标识，多个逗号分割',
  `remark` varchar(512) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '备注信息',
  `orderId` int(4) NULL DEFAULT NULL COMMENT '排序编号',
  `status` tinyint(2) NULL DEFAULT 1 COMMENT '菜单状态 (0.停用，1.启用)',
  `cache` tinyint(2) NULL DEFAULT NULL,
  `hideChildrenInMenu` tinyint(2) NULL DEFAULT NULL,
  `activeDir` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
  `createTime` datetime(0) NULL DEFAULT NULL COMMENT '创建时间',
  `createUserId` bigint(20) NULL DEFAULT NULL COMMENT '创建用户',
  `createUserName` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '创建用户名称',
  `updateUserId` bigint(20) NULL DEFAULT NULL COMMENT '更新用户',
  `updateUserName` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '创建用户名称',
  `updateTime` datetime(0) NULL DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 68 CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '菜单信息业务' ROW_FORMAT = Dynamic;

-- ----------------------------
-- Records of mortals_xhx_menu
-- ----------------------------
INSERT INTO `mortals_xhx_menu` VALUES (4, '数仓工作台', '/home', '', 0, 0, '', '', '', 1, 'pages/home/Home', 0, 0, 0, '', '', 0, 1, 0, 1, '', '2024-09-12 15:55:38', 1, '系统管理员', 1, '系统管理员', '2024-09-14 13:46:43');
INSERT INTO `mortals_xhx_menu` VALUES (5, '数据引擎', 'engine', '', 0, 0, '', '', '', 1, 'pages/engine/Engine', 0, 0, 0, '', '', 1, 1, 0, 1, '', '2024-09-12 16:03:55', 1, '系统管理员', 1, '系统管理员', '2024-09-14 13:46:49');
INSERT INTO `mortals_xhx_menu` VALUES (6, '排队取号系统', '/engine/queueupsystem', ',5', 5, 0, '', '', '', 1, 'pages/engine/QueueUpSystem', 1, 0, 0, '', '', 0, 1, 0, 1, '/engine', '2024-09-12 16:05:16', 1, '系统管理员', 1, '系统管理员', '2024-09-14 13:47:01');
INSERT INTO `mortals_xhx_menu` VALUES (7, '评价系统', '/engine/evaluatesystem', ',5', 5, 0, '', '', '', 1, 'pages/engine/EvaluateSystem', 1, 0, 0, '', '', 1, 1, 0, 1, '/engine', '2024-09-12 16:06:43', 1, '系统管理员', 1, '系统管理员', '2024-09-14 13:47:14');
INSERT INTO `mortals_xhx_menu` VALUES (8, '数据集市', 'market', '', 0, 0, '', '', '', 1, 'pages/market/Market', 0, 0, 0, '', '', 2, 1, 0, 1, '', '2024-09-12 16:07:19', 1, '系统管理员', 1, '系统管理员', '2024-09-14 13:47:25');
INSERT INTO `mortals_xhx_menu` VALUES (9, '排队数据报表', 'market/queueupreport', ',8', 8, 0, 'el-icon-s-operation', '', '', 1, 'pages/market/QueueUpReport', 1, 0, 0, '', '', 0, 1, 0, 1, 'market', '2024-09-12 16:08:12', 1, '系统管理员', 1, '系统管理员', '2024-09-14 13:47:31');
INSERT INTO `mortals_xhx_menu` VALUES (10, '评价数据报表', '/market/evaluatereport', ',8', 8, 0, 'el-icon-s-cooperation', '', '', 1, 'pages/market/EvaluateReport', 1, 0, 0, '', '', 1, 1, 0, 1, 'market', '2024-09-12 16:08:41', 1, '系统管理员', 1, '系统管理员', '2024-09-14 13:47:36');
INSERT INTO `mortals_xhx_menu` VALUES (11, '系统设置', 'system', '', 0, 0, '', '', '', 1, 'pages/system/System', 0, 0, 0, '', '', 3, 1, 0, 1, '', '2024-09-12 16:09:33', 1, '系统管理员', 1, '系统管理员', '2024-09-14 13:47:43');
INSERT INTO `mortals_xhx_menu` VALUES (12, '区县接入', '/system/access', ',11', 11, 0, 'el-icon-picture-outline', '', '', 1, '/pages/system/access/Access', 1, 0, 0, '', '', 0, 1, 0, 1, 'system', '2024-09-12 16:10:09', 1, '系统管理员', 1, '系统管理员', '2024-09-14 13:47:51');
INSERT INTO `mortals_xhx_menu` VALUES (13, '用户信息', '/system/user', ',11', 11, 0, 'el-icon-paperclip', '', '', 1, '/pages/system/user/User', 1, 0, 0, '', '', 1, 1, 0, 1, 'system', '2024-09-12 16:11:24', 1, '系统管理员', 1, '系统管理员', '2024-09-14 13:47:59');
INSERT INTO `mortals_xhx_menu` VALUES (14, '角色信息', 'system/role', ',11', 11, 0, 'el-icon-video-camera', '', '', 1, '/pages/system/role/Role', 1, 0, 0, '', '', 2, 1, 0, 1, 'system', '2024-09-12 16:12:15', 1, '系统管理员', 1, '系统管理员', '2024-09-14 13:48:05');
INSERT INTO `mortals_xhx_menu` VALUES (15, '资源信息', '/system/resourcemanage', ',11', 11, 0, 'el-icon-video-pause', '', '', 1, '/pages/system/resourceManage/ResourceManage', 1, 0, 0, '', '', 3, 1, 0, 1, 'system', '2024-09-12 16:13:07', 1, '系统管理员', 1, '系统管理员', '2024-09-14 13:48:12');
INSERT INTO `mortals_xhx_menu` VALUES (16, '菜单管理', '/system/menu', ',11', 11, 0, 'el-icon-s-help', '', '', 1, '/pages/system/menu/Menu', 1, 0, 0, '', '', 4, 1, 0, 1, 'system', '2024-09-12 16:13:48', 1, '系统管理员', 1, '系统管理员', '2024-09-14 13:48:18');
INSERT INTO `mortals_xhx_menu` VALUES (17, '系统参数', '/system/parameter', ',11', 11, 0, 'el-icon-s-order', '', '', 1, '/pages/system/parameter/Parameter', 1, 0, 0, '', '', 5, 1, 0, 1, 'system', '2024-09-12 16:14:24', 1, '系统管理员', 1, '系统管理员', '2024-09-14 13:48:25');
INSERT INTO `mortals_xhx_menu` VALUES (18, '任务信息', '/system/task', ',11', 11, 0, 'el-icon-reading', '', '', 1, '/pages/system/task/TaskSet', 1, 0, 0, '', '', 6, 1, 0, 1, 'system', '2024-09-12 16:14:55', 1, '系统管理员', 1, '系统管理员', '2024-09-14 13:48:31');
INSERT INTO `mortals_xhx_menu` VALUES (19, '系统日志', '/system/systemlogs', ',11', 11, 0, 'el-icon-box', '', '', 1, '/pages/system/systemlogs/SystemLogs', 1, 0, 0, '', '', 7, 1, 0, 1, 'system', '2024-09-12 16:15:50', 1, '系统管理员', 1, '系统管理员', '2024-09-14 13:48:37');
INSERT INTO `mortals_xhx_menu` VALUES (20, '查询', '', '', 6, 0, '', '', '', 1, '', 2, 0, 0, 'engine:queueupsystem:query', '', 0, 1, 0, 1, '', '2024-09-13 13:48:00', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (21, '数据导出', '', '', 6, 0, '', '', '', 1, '', 2, 0, 0, 'engine:queueupsystem:export', '', 1, 1, 0, 1, '', '2024-09-13 13:49:15', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (22, '查询', '', '', 7, 0, '', '', '', 1, '', 2, 0, 0, 'engine:queueupsystem:query', '', 0, 1, 0, 1, '', '2024-09-13 13:49:48', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (23, '数据导出', '', '', 7, 0, '', '', '', 1, '', 2, 0, 0, 'engine:queueupsystem:export', '', 1, 1, 0, 1, '', '2024-09-13 13:50:21', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (24, '数据搜索引擎', '', '', 5, 0, '', '', '', 1, '', 2, 0, 0, 'engine:enginesearch', '', 2, 1, 0, 1, '', '2024-09-13 13:51:49', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (25, '数据搜索', '', '', 5, 0, '', '', '', 1, '', 2, 0, 0, 'engine:query', '', 3, 1, 0, 1, '', '2024-09-13 14:01:14', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (26, '数据导出', '', '', 9, 0, '', '', '', 1, '', 2, 0, 0, 'market:queueupreport:export', '', 0, 1, 0, 1, '', '2024-09-13 14:59:32', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (27, '查询', '', '', 9, 0, '', '', '', 1, '', 2, 0, 0, 'market:queueupreport:query', '', 1, 1, 0, 1, '', '2024-09-13 14:59:50', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (28, '数据导出', '', '', 10, 0, '', '', '', 1, '', 2, 0, 0, 'market:evaluatereport:export', '', 0, 1, 0, 1, '', '2024-09-13 15:01:08', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (29, '查询', '', '', 10, 0, '', '', '', 1, '', 2, 0, 0, 'market:evaluatereport:query', '', 1, 1, 0, 1, '', '2024-09-13 15:01:26', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (30, '新增区县', '', ',11,12', 12, 0, '', '', '', 1, '', 2, 0, 0, 'system:access:add', '', 0, 1, 0, 1, '', '2024-09-13 15:06:47', 1, '系统管理员', 1, '系统管理员', '2024-09-18 10:58:20');
INSERT INTO `mortals_xhx_menu` VALUES (31, '删除区县', '', ',11,12', 12, 0, '', '', '', 1, '', 2, 0, 0, 'system:access:remove', '', 1, 1, 0, 1, '', '2024-09-13 15:07:10', 1, '系统管理员', 1, '系统管理员', '2024-09-18 10:58:26');
INSERT INTO `mortals_xhx_menu` VALUES (33, '查询区县', '', ',11,12', 12, 0, '', '', '', 1, '', 2, 0, 0, 'system:access:query', '', 4, 1, 0, 1, '', '2024-09-13 15:08:44', 1, '系统管理员', 1, '系统管理员', '2024-09-18 10:58:42');
INSERT INTO `mortals_xhx_menu` VALUES (34, '查询用户', '', ',11,13', 13, 0, '', '', '', 1, '', 2, 0, 0, 'system:user:query', '', 0, 1, 0, 1, '', '2024-09-13 15:09:30', 1, '系统管理员', 1, '系统管理员', '2024-09-18 10:58:12');
INSERT INTO `mortals_xhx_menu` VALUES (35, '分配角色', '', ',11,13', 13, 0, '', '', '', 1, '', 2, 0, 0, 'system:user:userRole', '', 1, 1, 0, 1, '', '2024-09-13 15:09:55', 1, '系统管理员', 1, '系统管理员', '2024-09-18 10:40:12');
INSERT INTO `mortals_xhx_menu` VALUES (36, '编辑区县', '', ',11,12', 12, 0, '', '', '', 1, '', 2, 0, 0, 'system:access:edit', '', 3, 1, 0, 1, '', '2024-09-13 15:11:22', 1, '系统管理员', 1, '系统管理员', '2024-09-18 10:58:36');
INSERT INTO `mortals_xhx_menu` VALUES (37, '详情', '', ',8,9', 9, 0, '', '', '', 1, '', 2, 0, 0, 'market:queueupreport:details', '', 2, 1, 0, 1, '', '2024-09-18 10:25:43', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (38, '详情', '', ',8,10', 10, 0, '', '', '', 1, '', 2, 0, 0, 'market:evaluatereport:details', '', 2, 1, 0, 1, '', '2024-09-18 10:26:28', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (42, '接入系统', '', ',11,12', 12, 0, '', '', '', 1, '', 2, 0, 0, 'system:access:accessSystem', '', 8, 1, 0, 1, '', '2024-09-18 10:31:34', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (44, '新增角色', '', ',11,14', 14, 0, '', '', '', 1, '', 2, 0, 0, 'system:role:add', '', 0, 1, 0, 1, '', '2024-09-18 10:42:13', 1, '系统管理员', 1, '系统管理员', '2024-09-18 10:57:38');
INSERT INTO `mortals_xhx_menu` VALUES (45, '删除角色', '', ',11,14', 14, 0, '', '', '', 1, '', 2, 0, 0, 'system:role:remove', '', 1, 1, 0, 1, '', '2024-09-18 10:42:37', 1, '系统管理员', 1, '系统管理员', '2024-09-18 10:57:46');
INSERT INTO `mortals_xhx_menu` VALUES (46, '编辑角色', '', ',11,14', 14, 0, '', '', '', 1, '', 2, 0, 0, 'system:role:edit', '', 2, 1, 0, 1, '', '2024-09-18 10:42:56', 1, '系统管理员', 1, '系统管理员', '2024-09-18 10:57:54');
INSERT INTO `mortals_xhx_menu` VALUES (47, '查询角色', '', ',11,14', 14, 0, '', '', '', 1, '', 2, 0, 0, 'system:role:query', '', 3, 1, 0, 1, '', '2024-09-18 10:43:24', 1, '系统管理员', 1, '系统管理员', '2024-09-18 10:58:01');
INSERT INTO `mortals_xhx_menu` VALUES (48, '分配资源', '', ',11,14', 14, 0, '', '', '', 1, '', 2, 0, 0, 'system:role:roleRes', '', 4, 1, 0, 1, '', '2024-09-18 10:44:10', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (49, '分配菜单', '', ',11,14', 14, 0, '', '', '', 1, '', 2, 0, 0, 'system:role:roleMenu', '', 5, 1, 0, 1, '', '2024-09-18 10:44:30', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (50, '新增资源', '', ',11,15', 15, 0, '', '', '', 1, '', 2, 0, 0, 'system:resourcemanage:add', '', 0, 1, 0, 1, '', '2024-09-18 10:47:25', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (51, '删除资源', '', ',11,15', 15, 0, '', '', '', 1, '', 2, 0, 0, 'system:resourcemanage:remove', '', 1, 1, 0, 1, '', '2024-09-18 10:47:41', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (52, '编辑资源', '', ',11,15', 15, 0, '', '', '', 1, '', 2, 0, 0, 'system:resourcemanage:edit', '', 2, 1, 0, 1, '', '2024-09-18 10:48:06', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (53, '查询资源', '', ',11,15', 15, 0, '', '', '', 1, '', 2, 0, 0, 'system:resourcemanage:query', '', 3, 1, 0, 1, '', '2024-09-18 10:48:21', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (54, '新增菜单', '', ',11,16', 16, 0, '', '', '', 1, '', 2, 0, 0, 'system:menu:add', '', 0, 1, 0, 1, '', '2024-09-18 10:51:43', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (55, '删除菜单', '', ',11,16', 16, 0, '', '', '', 1, '', 2, 0, 0, 'system:menu:remove', '', 1, 1, 0, 1, '', '2024-09-18 10:52:07', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (56, '编辑菜单', '', ',11,16', 16, 0, '', '', '', 1, '', 2, 0, 0, 'system:menu:edit', '', 2, 1, 0, 1, '', '2024-09-18 10:52:25', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (57, '菜单上移', '', ',11,16', 16, 0, '', '', '', 1, '', 2, 0, 0, 'system:menu:up', '', 3, 1, 0, 1, '', '2024-09-18 10:53:08', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (58, '菜单下移', '', ',11,16', 16, 0, '', '', '', 1, '', 2, 0, 0, 'system:menu:down', '', 4, 1, 0, 1, '', '2024-09-18 10:53:41', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (59, '新增参数', '', ',11,17', 17, 0, '', '', '', 1, '', 2, 0, 0, 'system:parameter:add', '', 0, 1, 0, 1, '', '2024-09-18 10:56:20', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (60, '删除参数', '', ',11,17', 17, 0, '', '', '', 1, '', 2, 0, 0, 'system:parameter:remove', '', 1, 1, 0, 1, '', '2024-09-18 10:56:39', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (61, '编辑参数', '', ',11,17', 17, 0, '', '', '', 1, '', 2, 0, 0, 'system:parameter:edit', '', 2, 1, 0, 1, '', '2024-09-18 10:57:05', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (62, '查询参数', '', ',11,17', 17, 0, '', '', '', 1, '', 2, 0, 0, 'system:parameter:query', '', 3, 1, 0, 1, '', '2024-09-18 10:57:18', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (63, '新增任务', '', ',11,18', 18, 0, '', '', '', 1, '', 2, 0, 0, 'system:task:add', '', 0, 1, 0, 1, '', '2024-09-18 11:00:37', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (64, '删除任务', '', ',11,18', 18, 0, '', '', '', 1, '', 2, 0, 0, 'system:task:remove', '', 1, 1, 0, 1, '', '2024-09-18 11:00:51', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (65, '编辑任务', '', ',11,18', 18, 0, '', '', '', 1, '', 2, 0, 0, 'system:task:edit', '', 2, 1, 0, 1, '', '2024-09-18 11:01:29', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (66, '查询任务', '', ',11,18', 18, 0, '', '', '', 1, '', 2, 0, 0, 'system:task:query', '', 3, 1, 0, 1, '', '2024-09-18 11:01:48', 1, '系统管理员', NULL, '', NULL);
INSERT INTO `mortals_xhx_menu` VALUES (67, '查询日志', '', ',11,19', 19, 0, '', '', '', 1, '', 2, 0, 0, 'system:systemlogs:query', '', 0, 1, 0, 1, '', '2024-09-18 11:05:18', 1, '系统管理员', NULL, '', NULL);

-- ----------------------------
-- Table structure for mortals_xhx_oper_log
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_oper_log`;
CREATE TABLE `mortals_xhx_oper_log`  (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `platformMark` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '平台标识',
  `userId` bigint(20) NULL DEFAULT NULL COMMENT '用户id',
  `userName` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '用户名称',
  `loginName` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '用户登录名',
  `requestUrl` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '请求地址',
  `content` varchar(2000) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '操作内容，记录操作具体信息，如修改前修改或的数据',
  `ip` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '操作IP地址',
  `logDate` datetime(0) NULL DEFAULT NULL COMMENT '操作时间',
  `operType` tinyint(2) NULL DEFAULT NULL COMMENT '操作类型，0：新增，1：修改，2：删除',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '操作日志' ROW_FORMAT = Dynamic;

-- ----------------------------
-- Records of mortals_xhx_oper_log
-- ----------------------------

-- ----------------------------
-- Table structure for mortals_xhx_param
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_param`;
CREATE TABLE `mortals_xhx_param`  (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '参数名称',
  `firstOrganize` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '一级组织，如：平台配置',
  `secondOrganize` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '二级组织，如：基础配置',
  `paramKey` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '参数键，全局唯一',
  `paramValue` varchar(2000) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '参数值',
  `validStatus` tinyint(2) NULL DEFAULT 1 COMMENT '参数有效状态，0：禁用，1：启用，默认1',
  `modStatus` tinyint(2) NULL DEFAULT 4 COMMENT '参数修改状态，0：隐藏，1：页面仅查看，2：页面可修改，3：页面可删除，4：页面可修改删除，默认4',
  `displayType` tinyint(2) NULL DEFAULT 0 COMMENT '展现类型，0：普通文本框，1：多行文本框，2：开关，3：块输入框，默认：0',
  `remark` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '备注',
  `createTime` datetime(0) NULL DEFAULT NULL COMMENT '创建时间',
  `createUserId` bigint(20) NULL DEFAULT NULL COMMENT '创建用户',
  `createUserName` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '创建用户名称',
  `updateUserId` bigint(20) NULL DEFAULT NULL,
  `updateTime` datetime(0) NULL DEFAULT NULL,
  `updateUserName` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL,
  PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 55 CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '参数信息' ROW_FORMAT = Dynamic;

-- ----------------------------
-- Records of mortals_xhx_param
-- ----------------------------
INSERT INTO `mortals_xhx_param` VALUES (1, '在线状态 ', 'Device', 'deviceOnlineStatus', '0', '离线', 1, 4, 0, 'deviceOnlineStatus', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (2, '在线状态 ', 'Device', 'deviceOnlineStatus', '1', '在线', 1, 4, 0, 'deviceOnlineStatus', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (3, '启用状态 ', 'Device', 'status', '0', '停止', 1, 4, 0, 'status', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (4, '启用状态 ', 'Device', 'status', '1', '启用', 1, 4, 0, 'status', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (5, '激活状态 ', 'Device', 'active', '0', '未激活', 1, 4, 0, 'active', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (6, '激活状态 ', 'Device', 'active', '1', '已激活', 1, 4, 0, 'active', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (7, '发送第三方平台消息类型', 'Platform', 'sendMsgType', '0', 'http', 1, 4, 0, 'sendMsgType', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (8, '发送第三方平台消息类型', 'Platform', 'sendMsgType', '1', 'jms', 1, 4, 0, 'sendMsgType', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (9, '是否启用发送消息', 'Platform', 'sendSwitch', '0', '停用', 1, 4, 0, 'sendSwitch', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (10, '是否启用发送消息', 'Platform', 'sendSwitch', '1', '启用', 1, 4, 0, 'sendSwitch', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (11, '日志类型，', 'DeviceLog', 'logType', '0', '上报事件', 1, 4, 0, 'logType', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (12, '日志类型，', 'DeviceLog', 'logType', '1', '下发服务', 1, 4, 0, 'logType', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (13, '数据获取方式', 'Device', 'deviceDataSourceWay', '1', '被动拉取', 1, 4, 0, 'deviceDataSourceWay', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (14, '服务对外接口地址', NULL, NULL, 'server_http_url', 'http://10.12.185.213:11078', 1, 4, 0, NULL, '2022-09-23 16:21:58', 1, '系统管理员', NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (15, '设备资源部署细致', NULL, NULL, 'distribute_path', '/home/publish/app/homeDeviceUrl', 1, 4, 0, NULL, '2022-11-14 10:02:41', 1, '系统管理员', NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (16, '前端对外地址', NULL, NULL, 'server_php_http_url', 'http://10.12.185.213:8090', 1, 4, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (17, '应用发布编码', 'appPublish', NULL, 'information-publish', '信息发布屏', 1, 4, 0, 'appPublish', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (18, '应用发布', 'appPublish', NULL, 'number-manager', '排号系统', 1, 4, 0, NULL, '2023-02-02 17:17:39', 1, '系统管理员', NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (19, '应用发布', 'appPublish', NULL, 'guide-manager', '导视后台管理', 1, 4, 0, NULL, '2023-02-02 17:29:05', 1, '系统管理员', NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (20, '应用发布', 'appPublish', NULL, 'base-manager-ui', '基础服务后台ui', 1, 4, 0, NULL, '2023-02-03 11:29:56', 1, '系统管理员', NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (21, '应用发布', 'appPublish', NULL, 'portal-manager-ui', '门户服务后台管理ui', 1, 4, 0, NULL, '2023-02-03 11:32:21', 1, '系统管理员', NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (22, '应用发布', 'appPublish', NULL, 'data-anaylse-ui', '数据分析前端', 1, 4, 0, NULL, '2023-02-04 11:22:26', 1, '系统管理员', NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (23, '应用发布', 'appPublish', NULL, 'device-manager-ui', '设备管理前端', 1, 4, 0, NULL, '2023-02-05 13:18:23', 1, '系统管理员', NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (24, '应用发布', 'appPublish', NULL, 'window-evaluate-ui', '窗口评价管理系统前端', 1, 4, 0, NULL, '2023-02-06 15:55:10', 1, '系统管理员', NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (25, '应用发布', 'appPublish', NULL, 'write-doc-manager-ui', '填单管理系统前端ui', 1, 4, 0, NULL, '2023-02-06 17:29:18', 1, '系统管理员', NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (26, '应用发布', 'appPublish', NULL, 'sample-form-manager-ui', '样表管理系统前端ui', 1, 4, 0, NULL, '2023-02-06 17:31:00', 1, '系统管理员', NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (28, '应用发布', 'appPublish', NULL, 'access-manager-ui', '存取件系统后端ui', 1, 4, 0, NULL, '2023-02-07 15:37:17', 1, '系统管理员', NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (29, '应用发布', 'appPublish', NULL, 'weChat-ui', '微官网后端ui', 1, 4, 0, NULL, '2023-02-14 15:48:03', 1, '系统管理员', NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (30, 'php通知公告', NULL, NULL, 'notice_url', 'http://172.15.28.116:8090/api/', 1, 4, 0, NULL, '2023-02-20 10:57:47', 1, '系统管理员', NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (31, '告警类型', 'AlarmConfig', 'alarmType', '0', '离线', 1, 4, 0, 'alarmType', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (32, '告警级别,', 'AlarmConfig', 'alarmLevel', '0', '危险', 1, 4, 0, 'alarmLevel', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (33, '告警级别,', 'AlarmConfig', 'alarmLevel', '1', '次要', 1, 4, 0, 'alarmLevel', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (34, '告警级别,', 'AlarmConfig', 'alarmLevel', '2', '一般', 1, 4, 0, 'alarmLevel', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (35, '推送方式,', 'AlarmConfig', 'alarmPusW1ay', '0', '推送站内消息', 1, 4, 0, 'alarmPusW1ay', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (36, '推送方式,', 'AlarmConfig', 'alarmPusW1ay', '1', '短信', 1, 4, 0, 'alarmPusW1ay', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (37, '是否启用', 'AlarmConfig', 'enabled', '0', '不启用', 1, 4, 0, 'enabled', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (38, '是否启用', 'AlarmConfig', 'enabled', '1', '启用', 1, 4, 0, 'enabled', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (39, '告警类型,', 'DeviceAlarmInfo', 'alarmType', '0', '离线', 1, 4, 0, 'alarmType', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (40, '告警级别', 'DeviceAlarmInfo', 'alarmLevel', '0', '危险', 1, 4, 0, 'alarmLevel', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (41, '告警级别', 'DeviceAlarmInfo', 'alarmLevel', '1', '次要', 1, 4, 0, 'alarmLevel', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (42, '告警级别', 'DeviceAlarmInfo', 'alarmLevel', '2', '一般', 1, 4, 0, 'alarmLevel', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (43, '告警状态,来自工单系统', 'DeviceAlarmInfo', 'alarmStatus', '0', '未清除', 1, 4, 0, 'alarmStatus', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (44, '告警状态,来自工单系统', 'DeviceAlarmInfo', 'alarmStatus', '1', '清除未确认', 1, 4, 0, 'alarmStatus', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (45, '告警状态,来自工单系统', 'DeviceAlarmInfo', 'alarmStatus', '2', '清除已确认', 1, 4, 0, 'alarmStatus', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (46, '是否部署', 'DeviceModuleDistribute', 'distribute', '0', '否', 1, 4, 0, 'distribute', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (47, '是否部署', 'DeviceModuleDistribute', 'distribute', '1', '是', 1, 4, 0, 'distribute', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (48, '应用类型', 'AppPublish', 'appType', '0', '前端', 1, 4, 0, 'appType', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (49, '应用类型', 'AppPublish', 'appType', '1', '后端', 1, 4, 0, 'appType', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (50, '是否部署', 'AppPublish', 'distribute', '0', '否', 1, 4, 0, 'distribute', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (51, '是否部署', 'AppPublish', 'distribute', '1', '是', 1, 4, 0, 'distribute', NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (53, '短信发送状态', 'AlarmSmsSend', 'sendStatus', '2', '发送成功', 1, 4, 0, NULL, '2023-11-28 11:14:54', 1, '系统管理员', NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` VALUES (54, '应用发布', 'appPublish', NULL, 'device-module', '设备管理系统3D模型', 1, 4, 0, NULL, '2024-02-29 14:22:36', 1, '系统管理员', NULL, NULL, NULL);

-- ----------------------------
-- Table structure for mortals_xhx_ph_queue
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_ph_queue`;
CREATE TABLE `mortals_xhx_ph_queue`  (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `ordernumber` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '预约编号，为空现场取号',
  `style` char(8) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '未叫号' COMMENT '叫号状态 (未叫号,叫号中,完成)',
  `business` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '业务名',
  `window_name` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '窗口名',
  `window_fromnum` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '窗口编号',
  `flownum` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '流水编号,当天的第xxx号',
  `formernum` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '呼叫转移号',
  `people_idcard` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '身份证号',
  `people_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '姓名',
  `people_sex` char(6) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '性别',
  `people_phone` varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '手机号',
  `workman_name` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '工作人员姓名',
  `workman_number` varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '工作人员工号',
  `taketime` datetime(0) NULL DEFAULT NULL COMMENT '取号时间',
  `calltime` datetime(0) NULL DEFAULT NULL COMMENT '叫号时间',
  `endtime` datetime(0) NULL DEFAULT NULL COMMENT '结束时间',
  `wait_time` int(9) NULL DEFAULT 0 COMMENT '等待时间,单位s',
  `handle_time` int(9) NULL DEFAULT 0 COMMENT '办理时间,单位s',
  `device_name` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '取号设备名',
  `call_name` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '呼叫设备',
  `matter_name` varchar(256) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '事项名',
  `queueid` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '排号队列ID，唯一',
  `wy_signin` varchar(16) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '现场取号' COMMENT '取号方式 (现场取号,微信取号)',
  `section_name` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '部门名称',
  `hall_name` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '大厅名称',
  `device_type` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '排号机' COMMENT '取号设备类型',
  `site_id` bigint(20) NULL DEFAULT 0 COMMENT '站点Id',
  `site_code` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '站点编码',
  `site_name` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '站点名称',
  `ext_num` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '扩展编号',
  `create_user_id` bigint(20) NULL DEFAULT NULL COMMENT '创建用户',
  `create_time` datetime(0) NOT NULL COMMENT '创建时间',
  `update_time` datetime(0) NULL DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  INDEX `style`(`style`) USING BTREE,
  INDEX `business`(`business`) USING BTREE,
  INDEX `window_fromnum`(`window_fromnum`) USING BTREE,
  INDEX `people_idcard`(`people_idcard`) USING BTREE,
  INDEX `people_phone`(`people_phone`) USING BTREE,
  INDEX `workman_number`(`workman_number`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '排号汇总' ROW_FORMAT = Dynamic;

-- ----------------------------
-- Records of mortals_xhx_ph_queue
-- ----------------------------

-- ----------------------------
-- Table structure for mortals_xhx_ph_queue_stat
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_ph_queue_stat`;
CREATE TABLE `mortals_xhx_ph_queue_stat`  (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'ID',
  `siteId` bigint(20) NULL DEFAULT 0 COMMENT '站点Id',
  `siteCode` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '站点编码',
  `siteName` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '站点名称',
  `business` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '业务名',
  `sectionName` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '部门',
  `hallName` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '大厅名称',
  `windowFromnum` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '窗口编号',
  `waitTime` int(9) NULL DEFAULT 0 COMMENT '平均等待时间,单位s',
  `phCount` int(9) NOT NULL COMMENT '取号数量',
  `year` int(9) NOT NULL COMMENT '年',
  `month` int(9) NOT NULL COMMENT '月',
  `day` int(9) NOT NULL COMMENT '日',
  `createTime` datetime(0) NOT NULL COMMENT '创建时间',
  `updateUserId` bigint(20) NULL DEFAULT NULL COMMENT '更新用户',
  `updateTime` datetime(0) NULL DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  INDEX `year`(`year`) USING BTREE,
  INDEX `month`(`month`) USING BTREE,
  INDEX `day`(`day`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '排队叫号汇总统计' ROW_FORMAT = Dynamic;

-- ----------------------------
-- Records of mortals_xhx_ph_queue_stat
-- ----------------------------

-- ----------------------------
-- Table structure for mortals_xhx_pj_evaluate
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_pj_evaluate`;
CREATE TABLE `mortals_xhx_pj_evaluate`  (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `people_idcard` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '评价人身份证号',
  `people_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '评价人姓名',
  `people_sex` char(6) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '评价人性别',
  `people_phone` varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '评价人手机号',
  `pj_option` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '评价选项(非常满意,满意,基本满意,不满意,非常不满意)',
  `content_tag` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '评价标签',
  `pic_url` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '评价人图片地址',
  `section_name` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '部门',
  `hall_name` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '大厅',
  `pj_source` varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '评价来源 (安卓,导视机,微信)',
  `opinion` varchar(512) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '手输意见',
  `window_name` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '窗口名',
  `window_fromnum` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '窗口编号',
  `flounum` varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '排号编号',
  `pjxt` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '窗口评价' COMMENT '窗口评价(自助服务终端,背靠背评价,微官网)',
  `workman_name` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '工作人员姓名',
  `workman_number` varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '工作人员工号',
  `devicenum` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '评价器mac',
  `evaluatestatus` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '等待评价' COMMENT '评价状态(等待评价,完成,截图有误,用户截图签名超时,用户评价超时,收到图片等待签名',
  `evaluatetype` char(8) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '截图' COMMENT '截图还是评价 (截图,评价)',
  `photobefor` varchar(256) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '截图地址',
  `photoautograph` varchar(256) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '签字图片',
  `picture` varchar(256) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '抓拍评价人照片',
  `process` varchar(256) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '音频视频地址',
  `eyevaluate` varchar(16) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '未标记' COMMENT '评价标记（未标记,标记非恶意差评,标记恶意差评)',
  `pj_type` varchar(16) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '窗口评价' COMMENT '评价指向 (窗口评价,部门评价,排号评价)',
  `pj_time` datetime(0) NULL DEFAULT NULL COMMENT '评价时间',
  `site_id` bigint(20) NULL DEFAULT 0 COMMENT '站点Id',
  `site_code` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '站点编码',
  `site_name` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '站点名称',
  `ext_num` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '扩展编号',
  `create_user_id` bigint(20) NULL DEFAULT NULL COMMENT '创建用户',
  `create_time` datetime(0) NOT NULL COMMENT '创建时间',
  `update_time` datetime(0) NULL DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  INDEX `people_idcard`(`people_idcard`) USING BTREE,
  INDEX `people_phone`(`people_phone`) USING BTREE,
  INDEX `pj_option`(`pj_option`) USING BTREE,
  INDEX `pj_source`(`pj_source`) USING BTREE,
  INDEX `site_id`(`site_id`) USING BTREE,
  INDEX `site_code`(`site_code`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '评价汇总' ROW_FORMAT = Dynamic;

-- ----------------------------
-- Records of mortals_xhx_pj_evaluate
-- ----------------------------

-- ----------------------------
-- Table structure for mortals_xhx_pj_evaluate_stat
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_pj_evaluate_stat`;
CREATE TABLE `mortals_xhx_pj_evaluate_stat`  (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'ID',
  `siteId` bigint(20) NULL DEFAULT 0 COMMENT '站点Id',
  `siteCode` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '站点编码',
  `siteName` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '站点名称',
  `sectionName` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '部门',
  `pjOption` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '评价选项(非常满意,满意,基本满意,不满意,非常不满意)',
  `windowFromnum` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '窗口编号',
  `hallName` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '大厅名称',
  `pjCount` int(9) NOT NULL COMMENT '评价数量',
  `year` int(9) NOT NULL COMMENT '年',
  `month` int(9) NOT NULL COMMENT '月',
  `day` int(9) NOT NULL COMMENT '日',
  `createTime` datetime(0) NOT NULL COMMENT '创建时间',
  `updateUserId` bigint(20) NULL DEFAULT NULL COMMENT '更新用户',
  `updateTime` datetime(0) NULL DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  INDEX `year`(`year`) USING BTREE,
  INDEX `month`(`month`) USING BTREE,
  INDEX `day`(`day`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '评价汇总统计' ROW_FORMAT = Dynamic;

-- ----------------------------
-- Records of mortals_xhx_pj_evaluate_stat
-- ----------------------------

-- ----------------------------
-- Table structure for mortals_xhx_resource
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_resource`;
CREATE TABLE `mortals_xhx_resource`  (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '菜单ID，主键，自增长',
  `name` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '名称',
  `groupName` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '分组名称',
  `url` varchar(2000) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '连接地址，多个地址以逗号分隔',
  `authType` tinyint(2) NULL DEFAULT 3 COMMENT '权限类型 (0.无限制，1.无需登录查看，2.需要登录查看，3.需要角色权限查看)',
  `sourceType` tinyint(2) NULL DEFAULT 0 COMMENT '资源类型，(0.系统资源，1.开放资源)',
  `createUserId` bigint(20) NOT NULL COMMENT '创建用户',
  `createUserName` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '创建用户名称',
  `createTime` datetime(0) NOT NULL COMMENT '创建时间',
  `updateUserId` bigint(20) NULL DEFAULT NULL COMMENT '更新用户',
  `updateUserName` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '创建用户名称',
  `updateTime` datetime(0) NULL DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 185 CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '资源信息业务' ROW_FORMAT = Dynamic;

-- ----------------------------
-- Records of mortals_xhx_resource
-- ----------------------------
INSERT INTO `mortals_xhx_resource` VALUES (1, '查看', '任务信息', '/task/view', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (2, '查看', '汇总统计', '/stat/info', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (3, '列表', '用户信息', '/user/list', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (4, '列表', '任务信息', '/task/list', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (5, '导出excel', '分表索引信息', '/table/index/exportExcel', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (6, '保存更新', '菜单信息', '/menu/save', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (7, '删除', '验证码信息', '/validcode/delete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (8, '逻辑删除', '角色资源权限', '/role/auth/logicDelete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (9, '查看', '参数信息', '/param/info', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (10, '查看', '参数信息', '/param/view', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (11, '导出excel', '统计日志', '/access/stat/log/exportExcel', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (12, '其它', '分表索引信息', '/table/index/add', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (13, '查看', '用户信息', '/user/view', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (14, '查看', '汇总统计', '/stat/view', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (15, '批量保存更新', '用户信息', '/user/batchSave', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (16, '导入excel', '评价汇总', '/pj/evaluate/importData', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (17, '导入excel', '区域接入系统', '/access/system/importData', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (18, '其它', '用户信息', '/user/change/password', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (19, '列表', '汇总统计', '/stat/list', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (20, '查看', '排队叫号汇总统计', '/ph/queue/stat/info', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (21, '保存更新', '验证码信息', '/validcode/save', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (22, '批量保存更新', '评价汇总', '/pj/evaluate/batchSave', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (23, '导出excel', '角色用户', '/role/user/exportExcel', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (24, '列表', '参数信息', '/param/list', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (25, '删除', '角色用户', '/role/user/delete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (26, '保存更新', '操作日志', '/oper/log/save', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (27, '批量保存更新', '角色用户', '/role/user/batchSave', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (28, '查看', '角色用户', '/role/user/info', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (29, '导入excel', '区域接入', '/access/importData', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (30, '导入excel', '资源信息', '/resource/importData', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (31, '菜单树列表', '菜单信息', '/menu/treeselect', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (32, '列表', '排队叫号汇总统计', '/ph/queue/stat/list', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (33, '根据角色编辑资源', '角色资源权限', '/role/auth/editResource', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (34, '删除', '区域接入系统', '/access/system/delete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (35, '根据用户id获取角色名称', '角色信息', '/role/roleNameByUserId', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (36, '导出excel', '资源信息', '/resource/exportExcel', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (37, '查看', '用户信息', '/user/info', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (38, '列表', '菜单信息', '/menu/list', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (39, '逻辑删除', '区域接入系统', '/access/system/logicDelete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (40, '查看', '排队叫号汇总统计', '/ph/queue/stat/view', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (41, '导出excel', '任务信息', '/task/exportExcel', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (42, '导入excel', '排号汇总', '/ph/queue/importData', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (43, '批量保存更新', '资源信息', '/resource/batchSave', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (44, '查看', '资源信息', '/resource/info', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (45, '分配资源', '角色资源权限', '/role/auth/distributionSource', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (46, '删除', '评价汇总统计', '/pj/evaluate/stat/delete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:07');
INSERT INTO `mortals_xhx_resource` VALUES (47, '查看', '任务信息', '/task/info', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (48, '导入excel', '参数信息', '/param/importData', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (49, '逻辑删除', '任务信息', '/task/logicDelete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (50, '保存更新', '汇总统计', '/stat/save', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (51, '导出excel', '角色资源权限', '/role/auth/exportExcel', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (52, '逻辑删除', '统计日志', '/access/stat/log/logicDelete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (53, '保存更新', '分表索引信息', '/table/index/save', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (54, '逻辑删除', '分表索引信息', '/table/index/logicDelete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (55, '逻辑删除', '角色用户', '/role/user/logicDelete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (56, '逻辑删除', '评价汇总统计', '/pj/evaluate/stat/logicDelete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (57, '查看', '验证码信息', '/validcode/view', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (58, '批量保存更新', '参数信息', '/param/batchSave', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (59, '删除', '菜单信息', '/menu/delete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (60, '查看', '操作日志', '/oper/log/view', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (61, '批量保存更新', '角色信息', '/role/batchSave', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (62, '删除', '评价汇总', '/pj/evaluate/delete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (63, '批量保存更新', '统计日志', '/access/stat/log/batchSave', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (64, '查看', '分表索引信息', '/table/index/view', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (65, '列表', '资源信息', '/resource/list', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (66, '导入excel', '菜单信息', '/menu/importData', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (67, '列表', '操作日志', '/oper/log/list', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (68, '保存更新', '排队叫号汇总统计', '/ph/queue/stat/save', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (69, '批量保存更新', '任务信息', '/task/batchSave', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (70, '逻辑删除', '参数信息', '/param/logicDelete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (71, '删除', '排队叫号汇总统计', '/ph/queue/stat/delete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (72, '查看', '资源信息', '/resource/view', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (73, '逻辑删除', '验证码信息', '/validcode/logicDelete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (74, '导入excel', '任务信息', '/task/importData', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (75, '更换排序', '菜单信息', '/menu/upOrDown', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (76, '根据parentId查询子信息', '菜单信息', '/menu/getListByParentId', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (77, '删除', '分表索引信息', '/table/index/delete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (78, '其它', '验证码信息', '/validcode/add', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (79, '导入excel', '评价汇总统计', '/pj/evaluate/stat/importData', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (80, '改变状态', '菜单信息', '/menu/change/status', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (81, '批量保存更新', '区域接入', '/access/batchSave', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (82, '导出excel', '区域接入系统', '/access/system/exportExcel', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (83, '分配菜单', '角色资源权限', '/role/auth/distributionMenu', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (84, '分配用户', '角色用户', '/role/user/distributionUser', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (85, '批量保存更新', '菜单信息', '/menu/batchSave', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (86, '批量保存更新', '操作日志', '/oper/log/batchSave', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (87, '逻辑删除', '评价汇总', '/pj/evaluate/logicDelete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (88, '保存更新', '参数信息', '/param/save', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (89, '删除', '汇总统计', '/stat/delete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (90, '查看', '操作日志', '/oper/log/info', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (91, '删除', '角色信息', '/role/delete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (92, '保存更新', '资源信息', '/resource/save', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (93, '逻辑删除', '用户信息', '/user/logicDelete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (94, '保存更新', '排号汇总', '/ph/queue/save', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (95, '逻辑删除', '排队叫号汇总统计', '/ph/queue/stat/logicDelete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (96, '导入excel', '角色用户', '/role/user/importData', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (97, '删除', '任务信息', '/task/delete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (98, '删除', '参数信息', '/param/delete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (99, '列表', '评价汇总统计', '/pj/evaluate/stat/list', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (100, '删除', '操作日志', '/oper/log/delete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (101, '查看', '角色信息', '/role/info', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (102, '查看', '区域接入', '/access/info', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (103, '查看', '排号汇总', '/ph/queue/info', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (104, '导入excel', '用户信息', '/user/importData', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (105, '导出excel', '操作日志', '/oper/log/exportExcel', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (106, '导出excel', '汇总统计', '/stat/exportExcel', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (107, '导入excel', '统计日志', '/access/stat/log/importData', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (108, '逻辑删除', '角色信息', '/role/logicDelete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (109, '批量保存更新', '排队叫号汇总统计', '/ph/queue/stat/batchSave', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (110, '下载模板', '验证码信息', '/validcode/downloadTemplate', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (111, '删除', '角色资源权限', '/role/auth/delete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (112, '保存更新', '区域接入系统', '/access/system/save', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (113, '查看', '角色信息', '/role/view', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (114, '查看', '排号汇总', '/ph/queue/view', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (115, '查看', '评价汇总统计', '/pj/evaluate/stat/info', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (116, '查看', '区域接入', '/access/view', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (117, '列表', '排号汇总', '/ph/queue/list', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (118, '列表', '角色信息', '/role/list', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (119, '批量保存更新', '角色资源权限', '/role/auth/batchSave', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (120, '批量保存更新', '汇总统计', '/stat/batchSave', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (121, '逻辑删除', '菜单信息', '/menu/logicDelete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (122, '查看', '评价汇总统计', '/pj/evaluate/stat/view', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (123, '其它', '任务信息', '/task/change/status', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (124, '保存更新', '评价汇总统计', '/pj/evaluate/stat/save', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (125, '查看', '角色资源权限', '/role/auth/info', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (126, '导出excel', '角色信息', '/role/exportExcel', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (127, '导入excel', '排队叫号汇总统计', '/ph/queue/stat/importData', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (128, '根据角色编辑菜单', '角色资源权限', '/role/auth/editMenu', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:08');
INSERT INTO `mortals_xhx_resource` VALUES (129, '逻辑删除', '汇总统计', '/stat/logicDelete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (130, '导出excel', '区域接入', '/access/exportExcel', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (131, '删除', '资源信息', '/resource/delete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (132, '逻辑删除', '操作日志', '/oper/log/logicDelete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (133, '导出excel', '参数信息', '/param/exportExcel', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (134, '删除', '排号汇总', '/ph/queue/delete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (135, '逻辑删除', '区域接入', '/access/logicDelete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (136, '查看', '角色资源权限', '/role/auth/view', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (137, '列表', '区域接入', '/access/list', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (138, '导出excel', '菜单信息', '/menu/exportExcel', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (139, '其它', '分表索引信息', '/table/index/edit', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (140, '导入excel', '角色信息', '/role/importData', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (141, '导出excel', '排号汇总', '/ph/queue/exportExcel', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (142, '保存更新', '统计日志', '/access/stat/log/save', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (143, '导入excel', '操作日志', '/oper/log/importData', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (144, '导出excel', '评价汇总', '/pj/evaluate/exportExcel', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (145, '导入excel', '角色资源权限', '/role/auth/importData', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (146, '导出excel', '验证码信息', '/validcode/exportExcel', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (147, '保存更新', '角色用户', '/role/user/save', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (148, '分配角色', '角色用户', '/role/user/distributionRole', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (149, '删除', '统计日志', '/access/stat/log/delete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (150, '导入excel', '分表索引信息', '/table/index/importData', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (151, '查看', '菜单信息', '/menu/view', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (152, '逻辑删除', '排号汇总', '/ph/queue/logicDelete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (153, '列表', '角色资源权限', '/role/auth/list', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (154, '批量保存更新', '评价汇总统计', '/pj/evaluate/stat/batchSave', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (155, '导出excel', '排队叫号汇总统计', '/ph/queue/stat/exportExcel', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (156, '保存更新', '评价汇总', '/pj/evaluate/save', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (157, '导出excel', '评价汇总统计', '/pj/evaluate/stat/exportExcel', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (158, '保存更新', '区域接入', '/access/save', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (159, '导出excel', '用户信息', '/user/exportExcel', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (160, '批量保存更新', '区域接入系统', '/access/system/batchSave', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (161, '逻辑删除', '资源信息', '/resource/logicDelete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (162, '导入excel', '验证码信息', '/validcode/importData', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (163, '查看', '菜单信息', '/menu/info', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (164, '其它', '验证码信息', '/validcode/edit', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (165, '列表', '角色用户', '/role/user/list', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (166, '保存更新', '用户信息', '/user/save', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (167, '查看', '角色用户', '/role/user/view', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (168, '导入excel', '汇总统计', '/stat/importData', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (169, '保存更新', '任务信息', '/task/save', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (170, '保存更新', '角色资源权限', '/role/auth/save', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (171, '查看', '评价汇总', '/pj/evaluate/info', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (172, '查看', '统计日志', '/access/stat/log/view', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (173, '查看', '评价汇总', '/pj/evaluate/view', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (174, '列表', '区域接入系统', '/access/system/list', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (175, '列表', '统计日志', '/access/stat/log/list', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (176, '删除', '区域接入', '/access/delete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (177, '批量保存更新', '排号汇总', '/ph/queue/batchSave', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (178, '删除', '用户信息', '/user/delete', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (179, '下载模板', '分表索引信息', '/table/index/downloadTemplate', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (180, '列表', '评价汇总', '/pj/evaluate/list', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (181, '查看', '区域接入系统', '/access/system/info', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (182, '保存更新', '角色信息', '/role/save', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (183, '查看', '统计日志', '/access/stat/log/info', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');
INSERT INTO `mortals_xhx_resource` VALUES (184, '查看', '区域接入系统', '/access/system/view', 3, 0, 1, 'admin', '2024-11-13 09:56:07', 1, '', '2024-11-13 09:56:09');

-- ----------------------------
-- Table structure for mortals_xhx_role
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_role`;
CREATE TABLE `mortals_xhx_role`  (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `name` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '角色名称',
  `remark` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '备注',
  `roleType` tinyint(2) NULL DEFAULT 2 COMMENT '角色类型 (0.系统内置角色,1.默认系统角色.2.普通角色)',
  `customerId` bigint(20) NULL DEFAULT NULL COMMENT '归属客户ID',
  `createUserId` bigint(20) NOT NULL COMMENT '创建用户',
  `createUserName` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '创建用户名称',
  `createTime` datetime(0) NOT NULL COMMENT '创建时间',
  `updateUserId` bigint(20) NULL DEFAULT NULL COMMENT '更新用户',
  `updateUserName` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '创建用户名称',
  `updateTime` datetime(0) NULL DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 3 CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '角色信息业务' ROW_FORMAT = Dynamic;

-- ----------------------------
-- Records of mortals_xhx_role
-- ----------------------------
INSERT INTO `mortals_xhx_role` VALUES (1, 'admin', '', 2, NULL, 1, '系统管理员', '2024-09-13 15:19:07', NULL, '', NULL);
INSERT INTO `mortals_xhx_role` VALUES (2, '测试', '', 2, NULL, 1, '系统管理员', '2024-09-14 09:21:04', NULL, '', NULL);

-- ----------------------------
-- Table structure for mortals_xhx_role_auth
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_role_auth`;
CREATE TABLE `mortals_xhx_role_auth`  (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `roleId` bigint(20) NULL DEFAULT NULL COMMENT '角色ID',
  `menuId` bigint(20) NULL DEFAULT NULL COMMENT '菜单ID',
  `resourceId` bigint(20) NULL DEFAULT NULL COMMENT '资源ID',
  `createUserId` bigint(20) NOT NULL COMMENT '创建用户',
  `createUserName` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '创建用户名称',
  `createTime` datetime(0) NOT NULL COMMENT '创建时间',
  `updateUserId` bigint(20) NULL DEFAULT NULL COMMENT '更新用户',
  `updateUserName` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '创建用户名称',
  `updateTime` datetime(0) NULL DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  INDEX `createUserId`(`createUserId`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 127 CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '角色资源权限业务' ROW_FORMAT = Dynamic;

-- ----------------------------
-- Records of mortals_xhx_role_auth
-- ----------------------------
INSERT INTO `mortals_xhx_role_auth` VALUES (100, 2, NULL, 3, 1, NULL, '2024-09-14 11:35:49', NULL, NULL, NULL);
INSERT INTO `mortals_xhx_role_auth` VALUES (101, 2, NULL, 13, 1, NULL, '2024-09-14 11:35:49', NULL, NULL, NULL);
INSERT INTO `mortals_xhx_role_auth` VALUES (102, 2, NULL, 15, 1, NULL, '2024-09-14 11:35:49', NULL, NULL, NULL);
INSERT INTO `mortals_xhx_role_auth` VALUES (103, 2, NULL, 18, 1, NULL, '2024-09-14 11:35:49', NULL, NULL, NULL);
INSERT INTO `mortals_xhx_role_auth` VALUES (104, 2, NULL, 37, 1, NULL, '2024-09-14 11:35:49', NULL, NULL, NULL);
INSERT INTO `mortals_xhx_role_auth` VALUES (105, 2, NULL, 93, 1, NULL, '2024-09-14 11:35:49', NULL, NULL, NULL);
INSERT INTO `mortals_xhx_role_auth` VALUES (106, 2, NULL, 104, 1, NULL, '2024-09-14 11:35:49', NULL, NULL, NULL);
INSERT INTO `mortals_xhx_role_auth` VALUES (107, 2, NULL, 159, 1, NULL, '2024-09-14 11:35:49', NULL, NULL, NULL);
INSERT INTO `mortals_xhx_role_auth` VALUES (108, 2, NULL, 166, 1, NULL, '2024-09-14 11:35:49', NULL, NULL, NULL);
INSERT INTO `mortals_xhx_role_auth` VALUES (109, 2, NULL, 178, 1, NULL, '2024-09-14 11:35:49', NULL, NULL, NULL);
INSERT INTO `mortals_xhx_role_auth` VALUES (126, 2, 4, NULL, 1, NULL, '2024-11-13 10:00:11', NULL, NULL, NULL);

-- ----------------------------
-- Table structure for mortals_xhx_role_user
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_role_user`;
CREATE TABLE `mortals_xhx_role_user`  (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `roleId` bigint(20) NULL DEFAULT NULL COMMENT '角色ID',
  `userId` bigint(20) NULL DEFAULT NULL COMMENT '用户ID',
  `createUserId` bigint(20) NOT NULL COMMENT '创建用户',
  `createUserName` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '创建用户名称',
  `createTime` datetime(0) NOT NULL COMMENT '创建时间',
  `updateUserId` bigint(20) NULL DEFAULT NULL COMMENT '更新用户',
  `updateUserName` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '创建用户名称',
  `updateTime` datetime(0) NULL DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  INDEX `createUserId`(`createUserId`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 3 CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '角色用户业务' ROW_FORMAT = Dynamic;

-- ----------------------------
-- Records of mortals_xhx_role_user
-- ----------------------------
INSERT INTO `mortals_xhx_role_user` VALUES (1, 1, 2097, 1, 'admin', '2024-09-15 01:20:00', NULL, NULL, NULL);
INSERT INTO `mortals_xhx_role_user` VALUES (2, 1, 2098, 1, 'admin', '2024-09-19 01:20:01', NULL, NULL, NULL);

-- ----------------------------
-- Table structure for mortals_xhx_stat
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_stat`;
CREATE TABLE `mortals_xhx_stat`  (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'ID',
  `siteId` bigint(20) NULL DEFAULT NULL COMMENT '站点Id',
  `siteCode` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '站点编码',
  `siteName` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '站点名称',
  `count` int(9) NOT NULL COMMENT '数量',
  `year` int(9) NOT NULL COMMENT '年',
  `month` int(9) NOT NULL COMMENT '月',
  `day` int(9) NOT NULL COMMENT '日',
  `createUserId` bigint(20) NULL DEFAULT NULL COMMENT '创建用户',
  `createTime` datetime(0) NOT NULL COMMENT '创建时间',
  `updateTime` datetime(0) NULL DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`) USING BTREE,
  INDEX `year`(`year`) USING BTREE,
  INDEX `month`(`month`) USING BTREE,
  INDEX `day`(`day`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '汇总统计' ROW_FORMAT = Dynamic;

-- ----------------------------
-- Records of mortals_xhx_stat
-- ----------------------------

-- ----------------------------
-- Table structure for mortals_xhx_table_index
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_table_index`;
CREATE TABLE `mortals_xhx_table_index`  (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '菜单ID，主键，自增长',
  `tableName` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '表名称',
  `tableMark` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '表标识',
  `createTime` datetime(0) NULL DEFAULT NULL COMMENT '创建时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '分表索引信息' ROW_FORMAT = Dynamic;

-- ----------------------------
-- Records of mortals_xhx_table_index
-- ----------------------------

-- ----------------------------
-- Table structure for mortals_xhx_task
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_task`;
CREATE TABLE `mortals_xhx_task`  (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '任务名称',
  `taskKey` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '任务关键字，区分任务执行流程',
  `status` tinyint(2) NULL DEFAULT 0 COMMENT '任务状态，0：未启动，1：执行中，默认0',
  `excuteService` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '任务执行服务',
  `excuteParam` text CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '任务执行参数',
  `excuteHost` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '任务执行主机，为空表示不限制任务的执行主机，多个用逗号分隔',
  `excuteStrategy` tinyint(2) NULL DEFAULT 1 COMMENT '执行策略，1：按日，2：按周，3：按月，4：按间隔时间，默认1',
  `excuteDate` int(11) NULL DEFAULT 0 COMMENT '执行日期，按日：则为0；按周：则为1-7；按月：则为：1-31；按间隔时间：则为间隔时间，单位：秒；默认0',
  `excuteTime` varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '00' COMMENT '执行时间，格式：HH:mm，默认：00:00',
  `remark` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '备注',
  `lastExcuteHost` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '最后执行主机',
  `lastExcuteTime` datetime(0) NULL DEFAULT NULL COMMENT '最后执行时间',
  `interimExcuteStatus` tinyint(2) NULL DEFAULT 0 COMMENT '临时执行状态，0：未启用，1：立即执行并保留，2：立即执行并删除，默认0',
  `createTime` datetime(0) NULL DEFAULT NULL COMMENT '创建时间',
  `createUserId` bigint(20) NULL DEFAULT NULL COMMENT '创建用户',
  `createUserName` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '创建用户名称',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 9 CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '任务信息' ROW_FORMAT = Dynamic;

-- ----------------------------
-- Records of mortals_xhx_task
-- ----------------------------
INSERT INTO `mortals_xhx_task` VALUES (2, '分表创建任务', 'tableIndexService', 0, 'tableIndexService', NULL, NULL, 1, 0, '00:30', NULL, '172.17.0.1', '2024-11-15 00:30:00', 0, '2021-08-12 11:07:23', 1, '系统管理员');
INSERT INTO `mortals_xhx_task` VALUES (7, '用户同步', 'syncUserTask', 0, 'SyncUserTask', NULL, NULL, 1, 0, '01:20', NULL, '172.17.0.1', '2024-11-15 01:20:01', 0, '2022-07-06 10:49:48', 1, '系统管理员');
INSERT INTO `mortals_xhx_task` VALUES (8, '报表统计', 'SiteStatTask', 0, 'SiteStatTask', '', '', 1, 3600, '16:12', '', '172.17.0.1', '2024-11-14 16:12:00', 0, '2024-03-01 10:59:53', 1, '系统管理员');

-- ----------------------------
-- Table structure for mortals_xhx_uploadfile
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_uploadfile`;
CREATE TABLE `mortals_xhx_uploadfile`  (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'ID，主键，自增长',
  `fileName` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '文件名称',
  `filePath` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '文件路径',
  `fileType` tinyint(2) NULL DEFAULT NULL COMMENT '文件类型，1 excel ,2 img,3 zip, 4 pdf',
  `createTime` datetime(0) NULL DEFAULT NULL COMMENT '创建时间',
  `createUser` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '创建用户',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '上传文件' ROW_FORMAT = Dynamic;

-- ----------------------------
-- Records of mortals_xhx_uploadfile
-- ----------------------------

-- ----------------------------
-- Table structure for mortals_xhx_user
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_user`;
CREATE TABLE `mortals_xhx_user`  (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '用户ID，主键，自增长',
  `loginName` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '登录名',
  `loginPwd` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '登录密码，使用md5双次加密',
  `loginLimitAddress` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '登录限制地址，多个IP地址用逗号分隔，可以使用IP段匹配，如：172.17.*非空：则只能该值内的IP可以登录',
  `realName` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '用户名',
  `mobile` varchar(21) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '用户手机号',
  `phone` varchar(21) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '用户联系电话',
  `email` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '用户邮箱',
  `qq` varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT 'QQ号码',
  `userType` tinyint(2) NULL DEFAULT NULL COMMENT '用户类型(0.系统用户,1.普通用户,2.工作人员)',
  `siteIds` varchar(512) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '所属站点id,多个逗号分隔',
  `areaCodes` varchar(512) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '所属区域code,多个逗号分隔',
  `status` tinyint(2) NULL DEFAULT NULL COMMENT '用户状态(0.停用，1.正常，2.冻结，3.销户，4.离职)',
  `createTime` datetime(0) NULL DEFAULT NULL COMMENT '创建时间',
  `createUserId` bigint(20) NULL DEFAULT NULL COMMENT '创建用户',
  `createUserName` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '创建用户名称',
  `lastLoginTime` datetime(0) NULL DEFAULT NULL COMMENT '最后一次登录时间',
  `lastLoginAddress` varchar(21) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '最后一次登录地址',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '用户信息业务' ROW_FORMAT = Dynamic;

-- ----------------------------
-- Records of mortals_xhx_user
-- ----------------------------

-- ----------------------------
-- Table structure for mortals_xhx_valid_code
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_valid_code`;
CREATE TABLE `mortals_xhx_valid_code`  (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '菜单ID，主键，自增长',
  `code` varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '验证码',
  `url` varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '校验地址，email校验使用',
  `mobile` varchar(21) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '校验手机号',
  `email` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '校验邮箱',
  `type` tinyint(2) NULL DEFAULT 0 COMMENT '校验方式，0：图片校验，1：手机校验，2：邮箱校验，默认0',
  `sessionId` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '会话ID',
  `ip` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT 'IP地址',
  `createTime` datetime(0) NULL DEFAULT NULL COMMENT '创建时间',
  `lapseTime` datetime(0) NULL DEFAULT NULL COMMENT '失效时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '验证码信息' ROW_FORMAT = Dynamic;

-- ----------------------------
-- Records of mortals_xhx_valid_code
-- ----------------------------

SET FOREIGN_KEY_CHECKS = 1;
